@@ -65,7 +65,7 @@ void ProfileModel::setProfileManager(ProfileManager *profileManager)
     m_profileManager = profileManager;
     if (m_profileManager) {
         // initial setting of signal mappings
-        connect(m_profileManager, SIGNAL(profileAdded(Learner*,int)), SLOT(onProfileAdded(Learner*,int)));
+        connect(m_profileManager, &ProfileManager::profileAdded, this, &ProfileModel::onProfileAdded);
         connect(m_profileManager, SIGNAL(profileAboutToBeRemoved(int)), SLOT(onProfilesAboutToBeRemoved(int)));
 
         // insert and connect all already existing profiles
